    
__all__ = [
    "__title__", "__summary__", "__uri__", "__version__", "__author__",
    "__email__", "__license__", "__copyright__",
]

__title__ = "pwrusb"
__summary__ = "A python wrapper for controlling pwrusb.com power strip outlets."
__uri__ = "https://github.com/henryroe/pwrusb"

# VERSION should be PEP386 compatible (http://www.python.org/dev/peps/pep-0386)
# pre-release of a version is, e.g. 0.2.1.dev1  (0.2.1 is *newer* than 0.2.1.dev1)
# post-release of a version is, e.g. 0.2.1-1  (0.2.1 is *older* than 0.2.1-1)
__version__ = "1.0.0-2"

__author__ = "Henry Roe"
__email__ = "hroe@hroe.me"

__license__ = "MIT License"
__copyright__ = "2016 %s" % __author__
